@@ -31,7 +31,6 @@
 */
 
 #include "kwidgetlister.h"
-#include "helper_p.h"
 
 #include <KLocalizedString>
 #include <KGuiItem>
@@ -49,15 +48,14 @@ class Q_DECL_HIDDEN KWidgetLister::Private
 {
 public:
     Private(KWidgetLister *qq)
-        : q(qq),
-          mBtnMore(nullptr),
-          mBtnFewer(nullptr),
-          mBtnClear(nullptr),
-          mLayout(nullptr),
-          mButtonBox(nullptr),
-          mMinWidgets(0),
-          mMaxWidgets(0)
-
+        : q(qq)
+        , mBtnMore(nullptr)
+        , mBtnFewer(nullptr)
+        , mBtnClear(nullptr)
+        , mLayout(nullptr)
+        , mButtonBox(nullptr)
+        , mMinWidgets(0)
+        , mMaxWidgets(0)
     {
     }
 
@@ -92,7 +90,8 @@ void KWidgetLister::Private::enableControls()
 }
 
 KWidgetLister::KWidgetLister(bool fewerMoreButton, int minWidgets, int maxWidgets, QWidget *parent)
-    : QWidget(parent), d(new Private(this))
+    : QWidget(parent)
+    , d(new Private(this))
 {
     d->mMinWidgets = qMax(minWidgets, 1);
     d->mMaxWidgets = qMax(maxWidgets, d->mMinWidgets + 1);
@@ -149,7 +148,6 @@ void KWidgetLister::init(bool fewerMoreButton)
     connect(d->mBtnClear, &QPushButton::clicked, this, &KWidgetLister::slotClear);
 
     d->enableControls();
-
 }
 
 void KWidgetLister::slotMore()
@@ -225,7 +223,7 @@ QWidget *KWidgetLister::createWidget(QWidget *parent)
 void KWidgetLister::setNumberOfShownWidgetsTo(int aNum)
 {
     int superfluousWidgets = qMax((int)d->mWidgetList.count() - aNum, 0);
-    int missingWidgets     = qMax(aNum - (int)d->mWidgetList.count(), 0);
+    int missingWidgets = qMax(aNum - (int)d->mWidgetList.count(), 0);
 
     // remove superfluous widgets
     for (; superfluousWidgets; superfluousWidgets--) {
@@ -258,18 +256,17 @@ void KWidgetLister::removeWidget(QWidget *widget)
     // The layout will take care that the
     // widget is removed from screen, too.
 
-    if (d->mWidgetList.count()  <= widgetsMinimum()) {
+    if (d->mWidgetList.count() <= widgetsMinimum()) {
         return;
     }
 
     const int index = d->mWidgetList.indexOf(widget);
-    QWidget *w =  d->mWidgetList.takeAt(index);
+    QWidget *w = d->mWidgetList.takeAt(index);
     w->deleteLater();
     w = nullptr;
     d->enableControls();
     Q_EMIT widgetRemoved(widget);
     Q_EMIT widgetRemoved();
-
 }
 
 void KWidgetLister::addWidgetAfterThisWidget(QWidget *currentWidget, QWidget *widget)
@@ -278,7 +275,7 @@ void KWidgetLister::addWidgetAfterThisWidget(QWidget *currentWidget, QWidget *wi
         widget = this->createWidget(this);
     }
 
-    int index = d->mLayout->indexOf(currentWidget ? currentWidget :  d->mButtonBox) + 1;
+    int index = d->mLayout->indexOf(currentWidget ? currentWidget : d->mButtonBox) + 1;
     d->mLayout->insertWidget(index, widget);
     if (currentWidget) {
         index = d->mWidgetList.indexOf(currentWidget);
@@ -292,4 +289,3 @@ void KWidgetLister::addWidgetAfterThisWidget(QWidget *currentWidget, QWidget *wi
     Q_EMIT widgetAdded();
     Q_EMIT widgetAdded(widget);
 }
-
